==> goods-center-api-2.7.41-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/SeckillAppItemPageQueries.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by sunyan on 2019/1/21.
 */
public class SeckillAppItemPageQueries implements Serializable {
    private static final long serialVersionUID = 2314426250450783654L;
    private Long appId;
    //类型
    private String type;
    //商品名称
    private String title;
    //参加秒杀商品id列表
    private List<Long> seckillIds;

    private int pageSize;
    private int pageNo;
    private int offset = -1;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<Long> getSeckillIds() {
        return seckillIds;
    }

    public void setSeckillIds(List<Long> seckillIds) {
        this.seckillIds = seckillIds;
    }

    public int getPageSize() {
        return pageSize;
    }

    public void setPageSize(int pageSize) {
        this.pageSize = pageSize;
    }

    public int getPageNo() {
        return pageNo;
    }

    public void setPageNo(int pageNo) {
        this.pageNo = pageNo;
    }

    public int getOffset() {
        return offset;
    }

    public void setOffset(int offset) {
        this.offset = offset;
    }

}

==> goods-center-api-2.9.2-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/SeckillAppItemPageQueries.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by sunyan on 2019/1/21.
 */
public class SeckillAppItemPageQueries implements Serializable {
    private static final long serialVersionUID = 2314426250450783654L;
    private Long appId;
    //类型
    private String type;
    //子类型
    private Integer subType;
    //商品名称
    private String title;
    //参加秒杀商品id列表
    private List<Long> seckillIds;

    private int pageSize;
    private int pageNo;
    private int offset = -1;
    //以前默认是开启，因此给默认值为true
    private boolean openAddrLimit = true;

    /**
     * 网点商品需要过滤
     */
    private List<Long> stationAppItemIds;

    public List<Long> getStationAppItemIds() {
        return stationAppItemIds;
    }

    public void setStationAppItemIds(List<Long> stationAppItemIds) {
        this.stationAppItemIds = stationAppItemIds;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public Integer getSubType() {
        return subType;
    }

    public void setSubType(Integer subType) {
        this.subType = subType;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<Long> getSeckillIds() {
        return seckillIds;
    }

    public void setSeckillIds(List<Long> seckillIds) {
        this.seckillIds = seckillIds;
    }

    public int getPageSize() {
        return pageSize;
    }

    public void setPageSize(int pageSize) {
        this.pageSize = pageSize;
    }

    public int getPageNo() {
        return pageNo;
    }

    public void setPageNo(int pageNo) {
        this.pageNo = pageNo;
    }

    public int getOffset() {
        return offset;
    }

    public void setOffset(int offset) {
        this.offset = offset;
    }

    public boolean getOpenAddrLimit() {
        return openAddrLimit;
    }

    public void setOpenAddrLimit(boolean openAddrLimit) {
        this.openAddrLimit = openAddrLimit;
    }
}
